@@ -1,3 +1,5 @@
+from django.utils.translation import gettext_lazy as _
+
 from djangocms_frontend.models import FrontendUIItem
 
 
@@ -9,6 +11,7 @@ class Alert(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Alert")
 
     def get_short_description(self):
-        return "({})".format(self.alert_context)
+        return f"({self.alert_context})"
