@@ -15,7 +15,7 @@ CAROUSEL_RIDE_CHOICES = (
 
 CAROUSEL_TEMPLATE_CHOICES = getattr(
     settings,
-    "DJANGOCMS_BOOTSTRAP5_CAROUSEL_TEMPLATES",
+    "DJANGOCMS_FRONTEND_CAROUSEL_TEMPLATES",
     (("default", _("Default")),),
 )
 
@@ -23,7 +23,7 @@ CAROUSEL_TEMPLATE_CHOICES = getattr(
 # {% with 1024 as width and 768 as height %}
 CAROUSEL_DEFAULT_SIZE = getattr(
     settings,
-    "DJANGOCMS_BOOTSTRAP5_CAROUSEL_DEFAULT_SIZE",
+    "DJANGOCMS_FRONTEND_CAROUSEL_DEFAULT_SIZE",
     [1024, 768],
 )
 
@@ -33,7 +33,7 @@ CAROUSEL_ASPECT_RATIOS = (
     (4, 3),
     (21, 9),
     (18, 9),
-) + tuple(getattr(settings, "DJANGOCMS_BOOTSTRAP5_CAROUSEL_ASPECT_RATIOS", tuple()))
+) + tuple(getattr(settings, "DJANGOCMS_FRONTEND_CAROUSEL_ASPECT_RATIOS", tuple()))
 
 CAROUSEL_ASPECT_RATIO_CHOICES = tuple(
     (f"{x}x{y}", f"{x}x{y}") for x, y in CAROUSEL_ASPECT_RATIOS
