@@ -1,10 +1,4 @@
-from django import forms
-from django.utils.translation import gettext_lazy as _
-from entangled.forms import EntangledModelFormMixin
-
 from djangocms_frontend import settings
-from djangocms_frontend.fields import ButtonGroup, ColoredButtonGroup
-from djangocms_frontend.helpers import insert_fields
 
 
 def get_row_cols_grid_values(instance):
@@ -34,10 +28,10 @@ class GridRowRenderMixin:
             instance.vertical_alignment,
             instance.horizontal_alignment,
         )
-        if instance.gutters or (
-            instance.parent and instance.parent.plugin_type == "CardPlugin"
-        ):  # no gutters if inside card
-            instance.add_classes("g-0")
+        if instance.parent and instance.parent.plugin_type == "CardPlugin":
+            instance.add_classes("g-0")  # no gutters if inside card
+        if instance.config.get("gutters", ""):
+            instance.add_classes(f"g-{instance.gutters}")
         instance.add_classes(get_row_cols_grid_values(instance))
         return super().render(context, instance, placeholder)
 
@@ -50,7 +44,7 @@ def get_grid_values(self):
             if isinstance(size, int) and (
                 element == "col" or element == "order" or element == "offset"
             ):
-                if size == 0 and element == "col":
+                if size == 0 and element == "col":  # 0 represents auto
                     size = "auto"
                 if device == "xs":
                     classes.append(f"{element}-{size}")
